SaveFileHeader

Trait SaveFileHeader 

pub trait SaveFileHeader {
    const VERSION: u32;
    const USER_FILE_INFO_MAX: u32;
    const FILE_SIZE_MAX: u32;

    // Required methods
    fn checksum(&self) -> Checksum;
    fn version(&self) -> u32;
    fn user_file_info_num(&self) -> u32;
    fn file_size(&self) -> u32;

    // Provided methods
    fn check_be(&self, buf: &[u8]) -> Result<(), CheckSaveFileError> { ... }
    fn check_le(&self, buf: &[u8]) -> Result<(), CheckSaveFileError> { ... }
    fn check(&self, buf: &[u8]) -> Result<(), CheckSaveFileError> { ... }
}
A trait for standardizing save file header implementation.

Required Associated Constants

const VERSION: u32

The expected version number of the save data.

const USER_FILE_INFO_MAX: u32

The maximum allowed number of user file descriptors.

const FILE_SIZE_MAX: u32

The maximum allowed size of the file, in bytes.

Required Methods

fn checksum(&self) -> Checksum

Returns the precomputed checksum derived from the file data.

fn version(&self) -> u32

Returns the version number of the save data.

fn user_file_info_num(&self) -> u32

Returns the number of stored user file descriptors.

fn file_size(&self) -> u32

Returns the size of the file, in bytes.

Provided Methods

fn check_be(&self, buf: &[u8]) -> Result<(), CheckSaveFileError>

Validates the save file header in big-endian.

fn check_le(&self, buf: &[u8]) -> Result<(), CheckSaveFileError>

Validates the save file header in little-endian.

fn check(&self, buf: &[u8]) -> Result<(), CheckSaveFileError>

Validates the save file header without validating the precomputed checksum.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors